pub struct ImageFileDelta {
pub detail: Option<Detail>,
pub file_id: Option<String>,
}Fields
detail: Option<Detail>Specifies the detail level of the image if specified by the user. low uses
fewer tokens, you can opt in to high resolution using high.
file_id: Option<String>The File ID of the image
in the message content. Set purpose="vision" when uploading the File if you
need to later display the file content.