pub struct ThreadCreateParams {
pub messages: Option<Vec<Message>>,
pub metadata: Option<Value>,
pub tool_resources: Option<ToolResources>,
}Fields
messages: Option<Vec<Message>>A list of messages to start the thread with.
metadata: Option<Value>Set of 16 key-value pairs that can be attached to an object. This can be useful for storing additional information about the object in a structured format. Keys can be a maximum of 64 characters long and values can be a maxium of 512 characters long.
tool_resources: Option<ToolResources>A set of resources that are made available to the assistant’s tools in this
thread. The resources are specific to the type of tool. For example, the
code_interpreter tool requires a list of file IDs, while the file_search
tool requires a list of vector store IDs.