pub struct ChatCompletionCreateParamsNonStreaming {
pub stream: Option<bool>,
}Fields
stream: Option<bool>If set, partial message deltas will be sent, like in ChatGPT. Tokens will be
sent as data-only
server-sent events
as they become available, with the stream terminated by a data: [DONE]
message.
Example Python code.