pub struct ChatCompletionSystemMessageParam {
pub content: String,
pub role: String,
pub name: Option<String>,
}Fields
content: StringThe contents of the system message.
role: StringThe role of the messages author, in this case system.
name: Option<String>An optional name for the participant. Provides the model information to differentiate between participants of the same role.